Contributing
============

Contributions are welcome.

Getting started
---------------

To work on the typed-models codebase, you'll want to clone the project locally
and install the required dependencies via `poetry <https://poetry.eustace.io>`_.

.. code-block:: bash

    $ git clone git@github.com:a2d24/typed-models.git
    $ poetry install